(define-module (alterator workflow backup-server)
    :use-module (srfi srfi-1)
    :use-module (srfi srfi-13)

    :use-module (alterator ahttpd)

    :use-module (alterator algo)
    :use-module (alterator str)
    :use-module (alterator woo)
    :use-module (alterator menu)

    :use-module (alterator http template)
    :use-module (alterator http html)

    :use-module (alterator ahttpd translate)
    :use-module (alterator ahttpd html)
    :use-module (alterator ahttpd workflow)
  :export (workflow))

;; main

(define (scm-content scm name)
  (call-with-current-continuation
    (lambda(return)
      (template
	scm (tag: name (lambda (options content) (return content))))
      '())))

(define (main-tag scm)
  (and (pair? scm)
       (tag: "div" (@ 'id "main") (scm-content scm "body"))))

(define (apply-po-domain scm po-domain)
  (if (string? po-domain)
    (template scm
	      (replace-tag: "html" (lambda (options content)
				     `(html ,@options ,@content
					    ,(@ 'po-domain po-domain)))))
    scm))

;; title and head merging

(define (title? x)
  (and (pair? x) (eq? (car x) 'title)))

(define (head-tag scm title)
  (and (pair? scm)
       (string? title)
       (replace-tag: "head"
		     (lambda(options content)
		       (list 'head
			     (remove title? content)
			     (remove title? (scm-content scm "head"))
			     (html: "title" title))))))

;; menu

(define (current-item? prefix-uri uri)
  (and (string? uri)
       (string? prefix-uri)
       (uri-prefix? prefix-uri uri)))

(define (html:menu-item x current-uri data)
  (let ((uri (menu-item-ref x 'uri)))
    (html: "div"
	   (@ 'class (if (current-item? uri current-uri) "menu-item-selected" "menu-item-normal"))
	   (html: "div"
		  (@ ' class "menu-name")
		  (html: "a" (@ 'href uri) (menu-item-ref x 'name)))
	   (html: "div"
		  (@ 'class "menu-summary")
		  (woo-get-option data (string->symbol (menu-item-ref x 'desktopfile)))))))

(define (menu-tag item-list current-uri data)
  (tag: "div" (@ 'id "menu")
	(map (lambda(item) (html:menu-item item current-uri data))
	     item-list)))

(define (find-item uri item-list)
  (find (lambda(x) (current-item? (menu-item-ref x 'uri) uri))
	item-list))

;;; main
(define (workflow url msg template-args)
  (cond
    ((string=? url "/") (html:redirect "/bacula/client-backup/archive"))
    (else
      (let* ((scm (cond-assq 'scm template-args))
	     (scm2 (process-module url msg))
	     (po-domain (and (pair? scm2) (find-po-domain scm2)))
	     (language (message-accept-language msg))
	     ;; menu
	     (all-item-list (filter (lambda(x) (string=? "X-Backup-Server" (menu-item-ref x 'category)))
				    (menu-list-item language)))
	     (current-item  (find-item url all-item-list))
	     (current-name  (menu-item-ref current-item 'name))
	     (current-uri   (menu-item-ref current-item 'uri)))
	(apply-po-domain
	  (template scm
		    (head-tag scm2 current-name)
		    (menu-tag all-item-list
			      current-uri
			      (woo-read-first "/backup-server-menu" 'language language))
		    (main-tag scm2))
	  po-domain)))))
