(define-module (ui backup-server network ajax)
    :use-module (alterator ajax)
    :use-module (alterator woo)
    :export (init))

(define (update-configuration . configuration)
  (let ((configuration (if (pair? configuration) (car configuration) (form-value "configuration"))))
    (form-update-activity
      '("ip" "mask" "default")
      (string=? configuration "static"))))

(define (read-interface . name)
  (let* ((name (if (pair? name) (car name) (form-value "name")))
	 (cmd (woo-read-first "/net-eth" 'name name)))

    (form-update-value-list
      '("name")
      cmd)
    (form-update-value-list
      '("computer_name" "dns" "search")
      cmd)
    (form-update-value-list
      '("adaptor" "ip" "mask" "default" "configuration")
      cmd)

    (update-configuration (woo-get-option cmd 'configuration))))

(define (write-interface . name)
  (catch/message
    (lambda()
      (let ((name (if (pair? name) (car name) (form-value "name"))))
        (woo-write
               "/backup-server-storage"
               'address (form-value "ip")
               'iface_configuration (form-value "configuration")
               'iface_name name)
	(apply woo-write
	       "/net-eth"
	       'name name
	       'commit #t
	       (form-value-list '("computer_name" "dns" "search"
				  "ip" "mask" "default" "configuration")))))))

(define (reset-interface)
  (let ((iface_name (woo-get-option (woo-read-first "/backup-server-storage") 'iface_name)))
      (form-update-enum "mask" (woo-list "/net-eth/avail_masks"))
      (form-update-enum "configuration" (woo-list "/net-eth/avail_configurations" 'language (form-value "language")))
      (read-interface iface_name)))

(define (init)
    (reset-interface)
    (form-bind "configuration" "change" update-configuration)
    (form-bind "apply" "click" write-interface)
    (form-bind "reset" "click" reset-interface))
