(document:surround "/std/frame")

;;; Functions

(define (update-configuration . configuration)
  (let ((configuration (if (pair? configuration) (car configuration) (form-value "configuration"))))
    (form-update-activity
      '("ip" "mask" "default")
      (string=? configuration "static"))))

(define (read-interface . name)
  (let* ((name (if (pair? name) (car name) (form-value "name")))
	 (cmd (woo-read-first "/net-eth" 'name name)))

    (form-update-value-list
      '("name")
      cmd)
    (form-update-value-list
      '("computer_name" "dns" "search")
      cmd)
    (form-update-value-list
      '("adaptor" "ip" "mask" "default" "configuration")
      cmd)

    (update-configuration (woo-get-option cmd 'configuration))))

(define (write-interface . name)
  (catch/message
    (lambda()
      (let ((name (if (pair? name) (car name) (form-value "name"))))
        (woo-write
               "/backup-server-storage"
               'address (form-value "ip")
               'iface_configuration (form-value "configuration")
               'iface_name name)
	(apply woo-write
	       "/net-eth"
	       'name name
	       'commit #t
	       (form-value-list '("computer_name" "dns" "search"
				  "ip" "mask" "default" "configuration")))))))

(define (reset-interface)
  (catch/message
    (lambda()
      (woo-write "/net-eth" 'reset #t)

      (form-update-enum "mask" (woo-list "/net-eth/avail_masks"))
      (form-update-enum "configuration" (woo-list "/net-eth/avail_configurations" 'language (form-value "language")))
      (form-update-enum "name" (woo-list "/net-eth/avail_ifaces"))

      (read-interface ""))))

;;; UI

(edit name "prev_name" text "" visibility #f)
(gridbox
  columns "0;100"
  margin "40"

  (label align "right" text (_ "Backup server interface:"))
  (combobox name "name")

  ;;
  (spacer)
  (textbox name "adaptor" max-height 60 alterability #f)

  ;;
  (label colspan 2)

  ;;
  (label text (_ "Configuration:") align "right" nameref "configuration")
  (combobox name "configuration")
  ;;
  (label text (_ "IP address:") align "right" nameref "ip")
  (edit name "ip")

  ;;
  (label text (_ "Netmask:") align "right" nameref "mask")
  (combobox name "mask")

  ;;
  (label text (_ "Default gateway:") align "right" nameref "default")
  (edit name "default")

  ;;
  (label text (_ "DNS servers:") nameref "dns" align "right")
  (edit name "dns")

  ;;
  (label text (_ "Search domains:") nameref "search" align "right")
  (edit name "search")

  ;;
  (spacer)
  (label text (small (_ "(multiple values should be space separated)")))

  ;;
  (label colspan 2)

  ;;
  (or (global 'frame:next)
      (label colspan 2))
  ;;
  (or (global 'frame:next)
      (button colspan 2 align "left" text (_ "Apply") name "apply")))

;;;;;;;;;;;;;;;;;;

(document:root
  (when loaded
    (reset-interface)
    (form-bind "name" "change" read-interface)
    (form-bind "configuration" "change" update-configuration)
    (or (global 'frame:next)(form-bind "apply" "click" write-interface))))

(frame:on-back (lambda() (or (write-interface) 'cancel)))
(frame:on-next (lambda() (or (write-interface) 'cancel)))

